#!/bin/bash

# Check for sudo/root privileges
if [ "$(id -u)" -ne 0 ]; then
  echo "Please run this script as root or with sudo."
  exit 1
fi

echo "Stopping and disabling all Bitdefender services..."
# Stop and disable the gz-evpsc service
systemctl stop gz-evpsc 2>/dev/null || echo "gz-evpsc service not running."
systemctl disable gz-evpsc 2>/dev/null || echo "gz-evpsc service not found."
systemctl daemon-reload

echo "Removing Bitdefender packages..."
# Bypass post-removal errors by renaming the problematic scripts
if [ -f /var/lib/dpkg/info/gz-evpsc.prerm ]; then
  mv /var/lib/dpkg/info/gz-evpsc.prerm /var/lib/dpkg/info/gz-evpsc.prerm.bak
  touch /var/lib/dpkg/info/gz-evpsc.prerm
  chmod +x /var/lib/dpkg/info/gz-evpsc.prerm
fi

# Force remove the package
dpkg --remove --force-remove-reinstreq gz-evpsc
apt autoremove --purge -y

echo "Cleaning up residual files and directories..."
# Remove directories related to gz-evpsc and Bitdefender
rm -rf /opt/bitdefender
rm -rf /var/lib/bitdefender
rm -rf /etc/bitdefender

echo "Removing Bitdefender repository entry..."
# Remove the repository from sources.list
sed -i '/deb http:\/\/download.bitdefender.com\/repos\/deb-hydra20-evpsc\//d' /etc/apt/sources.list
apt update

echo "Removing repository keys..."
# Remove Bitdefender repository key
apt-key del "$(apt-key list | grep -B1 'Bitdefender' | head -n1 | awk '{print $2}')"

echo "Cleaning up apt cache..."
# Clean package manager cache
apt clean
apt autoclean

echo "Verifying removal..."
# Check for remaining services or files
if systemctl list-units --type=service | grep -iq bitdefender; then
  echo "Some Bitdefender services are still running. Please check manually."
else
  echo "No Bitdefender services found."
fi

if find / -iname '*bitdefender*' 2>/dev/null | grep -q bitdefender; then
  echo "Some residual files or directories were found. Please check manually."
else
  echo "All Bitdefender files and directories have been removed."
fi

echo "Uninstallation completed."
