#!/bin/bash

# Check for sudo/root privileges
if [ "$(id -u)" -ne 0 ]; then
  echo "Please run this script as root or with sudo."
  exit 1
fi

# Add Bitdefender key and repository
echo "Adding Bitdefender key and repository..."
curl -sS https://download.bitdefender.com/repos/gzrepos.key.asc | apt-key add -
if ! grep -q "bitdefender non-free" /etc/apt/sources.list; then
  echo "deb http://download.bitdefender.com/repos/deb-hydra20-evpsc/ bitdefender non-free" | sudo tee -a /etc/apt/sources.list
fi

# Update package list
echo "Updating package list..."
apt update

# Install gz-evpsc package
echo "Installing Bitdefender gz-evpsc..."
apt install -y gz-evpsc

# Navigate to installation directory
cd /opt/bitdefender/gz-evpsc || { echo "Installation directory not found."; exit 1; }

# Get Syslog PORT and validate input
while true; do
  read -p "Enter the Syslog PORT (514 for tcp, 515 for udp): " SYSLOGPORT
  if [[ "$SYSLOGPORT" == "514" ]]; then
    TRANSPORT="tcp"
    break
  elif [[ "$SYSLOGPORT" == "515" ]]; then
    TRANSPORT="udp"
    break
  else
    echo "Invalid input! Please enter either '514' or '515'."
  fi
done

read -p "Enter the target IP or hostname: " TARGET
read -p "Enter your Bitdefender API key: " API_KEY

# Generate a 9-character random password
AUTH_PASSWORD=$(head /dev/urandom | tr -dc A-Za-z0-9 | head -c 9)
AUTH_STRING="Basic $(echo -n "test:$AUTH_PASSWORD" | base64)"

# Run config.sh
echo "Running config.sh..."
sudo ./config.sh 3200 "$SYSLOGPORT" "$TRANSPORT" "$TARGET" "$AUTH_STRING" config.json

# Check for generated certificates
CERT_PATH="/opt/bitdefender/gz-evpsc/api/config"
if [ -f "$CERT_PATH/server.key" ] && [ -f "$CERT_PATH/server.crt" ]; then
  echo "Certificates generated successfully."
else
  echo "Certificates were not generated! Config.sh might have failed."
  exit 1
fi

# Enable and start the service
echo "Enabling and starting the service..."
systemctl enable gz-evpsc
systemctl start gz-evpsc

# Create and execute CURL request
CURL_PAYLOAD=$(cat <<EOF
{
   "params": {
      "status": 1,
      "serviceType": "cef",
      "serviceSettings": {
           "url": "$TARGET",
           "authorization": "$AUTH_STRING",
           "requireValidSslCertificate": false
      },
      "subscribeToEventTypes": {
          "modules": true,
          "sva": true,
          "registration": true,
          "supa-update-status": true,
          "av": true,
          "aph": true,
          "fw": true,
          "avc": true,
          "uc": true,
          "dp": true,
          "sva-load": true,
          "task-status": true,
          "exchange-malware": true,
          "network-sandboxing": true,
          "adcloud": true,
          "exchange-user-credentials": true,
          "endpoint-moved-out": true, 
          "endpoint-moved-in": true,
          "troubleshooting-activity": true,
          "uninstall": true,
          "install": true,
          "hwid-change": true,
          "new-incident": true,
          "antiexploit": true,
          "network-monitor": true,
          "ransomware-mitigation": true,
          "security-container-update-available": true
       }
   },
   "jsonrpc": "2.0",
   "method": "setPushEventSettings",
   "id": "ad12cb61-52b3-4209-a87a-93a8530d91cb"
}
EOF
)

echo "Sending configuration to Bitdefender GravityZone API..."
curl --location 'https://cloudgz.gravityzone.bitdefender.com/api/v1.0/jsonrpc/push' \
--header 'Content-Type: application/json' \
--header "Authorization: Basic $API_KEY" \
--data "$CURL_PAYLOAD"

# Summary
echo "Installation and configuration completed."
echo "AUTH password: $AUTH_PASSWORD"
echo "Target IP/URL: $TARGET"
echo "API Key: $API_KEY"
echo "Config file: /opt/bitdefender/gz-evpsc/api/config/config.json"
echo "Certificates: $CERT_PATH/server.key and $CERT_PATH/server.crt"
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                         ## This script created by Berkay Erinc from Logsign Product Team